@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2015-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -26,6 +26,7 @@ import sys
 from .tools import (
     assert_equal,
     assert_not_equal,
+    require_commands,
     run,
     tempdir,
 )
@@ -34,6 +35,7 @@ here = os.path.dirname(__file__)
 target = here + '/target.py'
 
 def run_afl_showmap(stdin, xstdout=None, xstatus=0):
+    require_commands('py-afl-showmap', 'afl-showmap')
     with tempdir() as workdir:
         outpath = workdir + '/out'
         (stdout, stderr) = run(
@@ -53,7 +55,7 @@ def test_diff():
     assert_not_equal(out1, out2)
 
 def test_exception():
-    out = run_afl_showmap(b'\xff',
+    out = run_afl_showmap(b'\xFF',
         xstatus=2,
     )
     assert_not_equal(out, b'')
